<h1>Imbalanced Data Transform</h1>
<div class="photon-docu-header">
    <p>
        We have a simple solution for imbalanced classes in a classification problem. 
    Based on the <a href="https://imbalanced-learn.readthedocs.io/en/stable/index.html" target="_blank"> 
    imbalanced-learn package</a>, you can choose between over-, under- and combinesampling. 
    Have a look at the <a href="https://imbalanced-learn.readthedocs.io/en/stable/index.html" target="_blank"> Developer Website</a> for
        details  about the balancing data algorithms. 
    </p>
</div>

``` python hl_lines="32-34"
{% include "examples/basic/imbalanced_data.py" %} 
```

